package net.sf.sidaof.datasource;

import java.sql.Connection;
import java.sql.DatabaseMetaData;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import javax.sql.DataSource;

import net.sf.sidaof.domain.DataSourceMetadata;

/**
 * Class to obtain and hold metadata info on a datasource.
 * 
 * @author Jeff Jensen
 */
public class DataSourceInspector {
    public static DataSourceMetadata makeDataSourceMetadata(DataSource ds) {
        DataSourceMetadata dsm = new DataSourceMetadata();
        try {
            Connection c = ds.getConnection();
            DatabaseMetaData md = c.getMetaData();

            dsm.setDbMajorVersion(md.getDatabaseMajorVersion());
            dsm.setDbMinorVersion(md.getDatabaseMinorVersion());
            dsm.setProductName(md.getDatabaseProductName());
            dsm.setProductVersion(md.getDatabaseProductVersion());
            dsm.setDriverMajorVersion(md.getDriverMajorVersion());
            dsm.setDriverMinorVersion(md.getDriverMinorVersion());
            dsm.setDriverName(md.getDriverName());
            dsm.setDriverVersion(md.getDriverVersion());
            dsm.setJdbcMajorVersion(md.getJDBCMajorVersion());
            dsm.setJdbcMinorVersion(md.getJDBCMinorVersion());
            dsm.setUrl(md.getURL());
            dsm.setUser(md.getUserName());

            c.close();
        } catch (SQLException e) {
            dsm.setException(e);
        }
        return dsm;
    }

    /**
     * Convert a collection of DataSource to a list of DataSourceInspector.
     * 
     * @param dataSourceList
     *            The collection of DataSource to convert to list of
     *            DataSourceInspector.
     * @return The list of DataSourceInspector converted from the DataSource
     *         list parameter.
     */
    public static List<DataSourceMetadata> makeDataSourceMetadataList(
            Collection<DataSource> dataSourceList) {
        List<DataSourceMetadata> list = new ArrayList<DataSourceMetadata>();
        for (DataSource ds : dataSourceList) {
            DataSourceMetadata dsm =
                    DataSourceInspector.makeDataSourceMetadata(ds);
            list.add(dsm);
        }
        return list;
    }
}
